Language enum

语言枚举 en 英文,cn简体中文,tw繁体,in印尼

Inheritance
Available extensions

Values

en → const Language
cn → const Language
tw → const Language
In → const Language

Properties

countryCode String

Available on Language, provided by the LanguageExten extension

no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
languageCode String

Available on Language, provided by the LanguageExten extension

no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
name String

Available on Language, provided by the LanguageExten extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Language>
A constant List of the values in this enum, in order of their declaration.